<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="../../src/ui/about.ui" line="19"/>
        <source>About QAntenna</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="90"/>
        <source>&lt;version&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="103"/>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="115"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;QAntenna&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;A multiplatform antenna and radiation pattern analyzer&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;http://qantenna.sf.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;http://qantenna.sf.net/&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="145"/>
        <source>A&amp;uthors</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../../src/ui/about.ui" line="157"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Lisandro Damián Nicanor Pérez Meyer&lt;br /&gt;&lt;a href=&quot;perezmeyer@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;perezmeyer@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Gustavo Gonzalez&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;gonzalgustavo@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;br /&gt;&lt;br /&gt;Pablo Odorico&lt;br /&gt;&lt;a href=&quot;gonzalgustavo@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;pablo.odorico@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="180"/>
        <source>&amp;Thanks To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="242"/>
        <source>&amp;License Agreement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="254"/>
        <source>This program is distributed under the terms of the  GNU General Public License Version 2&lt;br&gt;&lt;br&gt;Available &lt;a href=&quot;http://www.gnu.org/copyleft/gpl.html&quot;&gt;online&lt;/a&gt; or in the COPYING file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/ui/about.ui" line="198"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:12pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Joop Stakenborg&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Correct installation of translation files in UNIX systems&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Dutch Translation&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Testing&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Michael Barjenbruch&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - INSTALL file&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - German translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Louis Belmont&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - French translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marcin Gucia&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Polish translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marina Goritskaia&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Russian translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Peter Isaksen&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt; - Danish translation&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Marc Ume&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Original yagi8sq_ch1.nec example&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Everaldo&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;  - Icons&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Claudio Delrieux&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;Ricardo Coppo&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;Gustavo Ramoscelli&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;T.C.A. Molteno&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:600;&quot;&gt;N. Kyriazis&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt;&quot;&gt;See examples/LICENSE-NEC.FILES for more information on the NEC examples&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DataManager</name>
    <message>
        <location filename="../../src/datamanager.cpp" line="248"/>
        <source>Closing</source>
        <translation>Fermeture</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="273"/>
        <source>NEC files (*.nec)</source>
        <translation>fichiers NEC (*.nec)</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="273"/>
        <source>All files (*.*)</source>
        <translation>Tous les fichiers (*.*)</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="292"/>
        <source>The file &quot;</source>
        <translation>Le fichier &quot;</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="292"/>
        <source>&quot; is already open.</source>
        <translation>&quot; est déjà ouvert.</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="313"/>
        <source>Opening</source>
        <translation>Ouverture</translation>
    </message>
    <message>
        <location filename="../../src/datamanager.cpp" line="86"/>
        <source>Calculating</source>
        <translation>Calculs en cours</translation>
    </message>
</context>
<context>
    <name>GLWidget</name>
    <message>
        <location filename="../../src/glwidget.cpp" line="294"/>
        <source>Exploration mode: Use W, S, A and D keys to go forward, backward or move sideways</source>
        <translation>Mode Exploration : utilisez les touches W, S, A, D pour les déplacements avant, arrière, et les déplacements latéraux</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="334"/>
        <source>Orbital mode: Move around the antenna by dragging it</source>
        <translation>Mode Orbital: Déplacez-vous autour de la caméra en la faisant glisser</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="395"/>
        <source>QAntenna - DataManager</source>
        <translation>QAntenna - DataManager</translation>
    </message>
    <message>
        <location filename="../../src/glwidget.cpp" line="396"/>
        <source>I can not create the OpenGL list for the grid</source>
        <translation>Echec de la création de liste OpenGL pour la grille</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="161"/>
        <source>Welcome to</source>
        <translation>Bienvenue à</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
        <location filename="../../src/ui/mainwindow.cpp" line="446"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="325"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="498"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="500"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="544"/>
        <source>([0-9]+) *x *([0-9]+)</source>
        <translation>([0-9]+) *x *([0-9]+)</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="548"/>
        <source>Render into file</source>
        <translation>Rendu vers le fichier</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="549"/>
        <source>Enter the desired resolution:</source>
        <translation>Entrez la résolution désirée:</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="550"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="588"/>
        <source>%1 file (*.%2);;</source>
        <translation>%1 fichier (*.%2);;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="596"/>
        <source>Save Image As</source>
        <translation>Enregistrer l&apos;image sous</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="613"/>
        <source>Rendering to &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
        <translation>Rendu vers &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="618"/>
        <source>Unable to save %1.</source>
        <translation>Echec de la sauvegarde de %1.</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="629"/>
        <source>Rendering to clipboard... </source>
        <translation>Enregistrement du rendu dans le presse-papier...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="257"/>
        <source>Calculating...</source>
        <translation>Calculs en cours...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="279"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="286"/>
        <source>Some antennas need to be calculated</source>
        <translation>Certaines antennes on besoin d&apos;être calculées</translation>
    </message>
</context>
<context>
    <name>MainWindowQAntenna</name>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="19"/>
        <source>QAntenna</source>
        <translation>QAntenna</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="242"/>
        <source>File</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="268"/>
        <source>[Path]</source>
        <translation>[Chemin d&apos;accès]</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="273"/>
        <source>[Index]</source>
        <translation>[Index]</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="310"/>
        <source>Calculate at opening</source>
        <translation>Calculer à l&apos;ouverture</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="473"/>
        <source>Visualization</source>
        <translation>Visualisation</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="757"/>
        <source>Modes</source>
        <translation>Modes</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="780"/>
        <source>Surface</source>
        <translation>Surface</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="787"/>
        <source>Spheres</source>
        <translation>Sphères</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="794"/>
        <source>Mesh</source>
        <translation>Maillage</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="801"/>
        <source>Volumetric</source>
        <translation>Volumétrique</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="502"/>
        <source>Pattern scale</source>
        <translation>Echelle du diagramme</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="509"/>
        <source>Transparency</source>
        <translation>Transparence</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="516"/>
        <source>Spheres radius</source>
        <translation>Rayon des sphères</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="523"/>
        <source>Segment radius</source>
        <translation>Rayon des segments</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="676"/>
        <source>Minimum dB at the origin</source>
        <translation>dB minimum à l&apos;origine</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="878"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="885"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="937"/>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="951"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="965"/>
        <source>C&amp;lose all</source>
        <translation>Fermer &amp;Tout</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="378"/>
        <source>History:</source>
        <translation>Historique:</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="388"/>
        <source>Clean history</source>
        <translation>Effacer l&apos;historique</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="92"/>
        <source>Open file...</source>
        <translation>Ouvrir un fichier...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="116"/>
        <source>Close file...</source>
        <translation>Fermer le fichier ...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="912"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="915"/>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="918"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="929"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="940"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="954"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="976"/>
        <source>C&amp;alculate patterns</source>
        <translation>C&amp;alculer les diagrammes</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="979"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="998"/>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1001"/>
        <source>Render to file</source>
        <translation>Rendu vers le fichier</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1004"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1015"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="95"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="119"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="132"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="164"/>
        <source>A</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="350"/>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="808"/>
        <source>Show grid</source>
        <translation>Montrer la grille</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="896"/>
        <source>&amp;Tools</source>
        <translation>&amp;Outils</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="926"/>
        <source>&amp;About...</source>
        <translation>&amp;A propos de...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="987"/>
        <source>About &amp;Qt...</source>
        <translation>A propos de &amp;Qt...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="995"/>
        <source>&amp;Render to file...</source>
        <translation>&amp;Rendu vers le fichier...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="1012"/>
        <source>Render to &amp;clipboard...</source>
        <translation>Rendu vers le &amp;presse-papier...</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="453"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Nimbus Sans L&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="247"/>
        <source> Frequency</source>
        <translation>Fréquence</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindowqantenna.ui" line="252"/>
        <source> Calculated </source>
        <translation>Calcul terminé</translation>
    </message>
</context>
<context>
    <name>NECContainer</name>
    <message>
        <location filename="../../src/neccontainer.cpp" line="225"/>
        <source>Rendering &quot;&lt;font color=&quot;#000066&quot;&gt;</source>
        <translation>Rendu de &quot;&lt;font color=&quot;#000066&quot;&gt;</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/main.cpp" line="77"/>
        <source>Loading QAntenna</source>
        <translation>Chargement de QAntenna</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="66"/>
        <source>Checking if there is OpenGL support in this machine</source>
        <translation>Recherche de prise en charge OpenGL</translation>
    </message>
</context>
<context>
    <name>QWidget</name>
    <message>
        <location filename="../../src/necinput.cpp" line="137"/>
        <source>While trying to insert a FR card, I could not find a GE card in order to put the first card in a right place</source>
        <translation>QAntenna n&apos;a pas pu trouver de carte GE permet d&apos;insérer la carte FR</translation>
    </message>
    <message>
        <location filename="../../src/necinput.cpp" line="982"/>
        <source>I could not create/open input.necin</source>
        <translation>Echec à la création/ouverture de input.necin</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="117"/>
        <location filename="../../src/necinputparser.cpp" line="205"/>
        <source>The following line can not be parsed properly</source>
        <translation>La ligne suivante n&apos;a pu être interprétée correctement</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="119"/>
        <location filename="../../src/necinputparser.cpp" line="207"/>
        <source>The string list is</source>
        <translation>La liste de chaînes de caractères est</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="226"/>
        <location filename="../../src/necinputparser.cpp" line="234"/>
        <location filename="../../src/necinputparser.cpp" line="244"/>
        <source>QAntenna - NEC input parser</source>
        <translation>QAntenna - Analyseur syntaxique d&apos;entrées NEC</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="227"/>
        <source>The file does not exists</source>
        <translation>Le fichier n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="235"/>
        <source>I can not read the file</source>
        <translation>Le fichier n&apos;a pu être lu</translation>
    </message>
    <message>
        <location filename="../../src/necinputparser.cpp" line="245"/>
        <source>The file is empty</source>
        <translation>Le fichier est vide</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="69"/>
        <source>We don&apos;t have OpenGL support</source>
        <translation>Pas de prise en charge OpenGL</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="71"/>
        <source>There is no OpenGL support in your system.&lt;br&gt;Closing QAntenna</source>
        <translation>Votre système ne possède pas de prise en charge OpenGL.&lt;br&gt;Fermeture de Qantenna</translation>
    </message>
</context>
</TS>
